==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftAPIServerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftAPIServerSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecBuilder>{
  public OpenShiftAPIServerSpecBuilder() {
    this(false);
  }
  public OpenShiftAPIServerSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftAPIServerSpec(), validationEnabled);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftAPIServerSpec(), validationEnabled);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance) {
    this(fluent, instance, false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance) {
    this(instance,false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec build() {
    OpenShiftAPIServerSpec buildable = new OpenShiftAPIServerSpec(fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getUnsupportedConfigOverrides());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftAPIServerSpecBuilder that = (OpenShiftAPIServerSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/OpenShiftAPIServerSpecBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpenShiftAPIServerSpecBuilder extends io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluentImpl<io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecBuilder>{
  public OpenShiftAPIServerSpecBuilder() {
    this(false);
  }
  public OpenShiftAPIServerSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new OpenShiftAPIServerSpec(), validationEnabled);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpenShiftAPIServerSpec(), validationEnabled);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance) {
    this(fluent, instance, false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLogLevel(instance.getLogLevel()); 
    fluent.withManagementState(instance.getManagementState()); 
    fluent.withObservedConfig(instance.getObservedConfig()); 
    fluent.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    fluent.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance) {
    this(instance,false);
  }
  public OpenShiftAPIServerSpecBuilder(io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLogLevel(instance.getLogLevel()); 
    this.withManagementState(instance.getManagementState()); 
    this.withObservedConfig(instance.getObservedConfig()); 
    this.withOperatorLogLevel(instance.getOperatorLogLevel()); 
    this.withUnsupportedConfigOverrides(instance.getUnsupportedConfigOverrides()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.OpenShiftAPIServerSpec build() {
    OpenShiftAPIServerSpec buildable = new OpenShiftAPIServerSpec(fluent.getLogLevel(),fluent.getManagementState(),fluent.getObservedConfig(),fluent.getOperatorLogLevel(),fluent.getUnsupportedConfigOverrides());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenShiftAPIServerSpecBuilder that = (OpenShiftAPIServerSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
